@@ -10,42 +10,42 @@ def db():
     yield db
 
 
-def testTransmissibility(db):
+def testTransmissibility(db) -> None:
     converted = db.Convert("transmissibility", "cp.m3/day/bar", "cp.bbl/day/psi", 1.0)
     assert approx(converted) == 0.433667315
 
 
-def testIndex(db):
+def testIndex(db) -> None:
     category = db.GetCategoryInfo("index")
     db.CheckQuantityTypeUnit(category.quantity_type, "<ind>")
 
 
-def testAdsorptionRate(db):
+def testAdsorptionRate(db) -> None:
     db.CheckQuantityTypeUnit("adsorption rate", "mg/kg/d")
     assert approx(db.Convert("adsorption rate", "mg/kg/d", "kg/kg/d", 1.0)) == 1.0e-6
 
 
-def testSolubilityProduct(db):
+def testSolubilityProduct(db) -> None:
     db.CheckQuantityTypeUnit("solubility product", "(mol/m3)^2")
     assert approx(db.Convert("solubility product", "(mol/L)^2", "(mol/m3)^2", 1.0)) == 1.0e6
 
 
-def testMassConsumptionEfficiency(db):
+def testMassConsumptionEfficiency(db) -> None:
     db.CheckQuantityTypeUnit("mass consumption efficiency", "mg/l/mg/l")
     db.CheckQuantityTypeUnit("mass consumption efficiency", "kg/m3/kg/m3")
 
 
-def testDensityGeneration(db):
+def testDensityGeneration(db) -> None:
     db.CheckQuantityTypeUnit("density generation", "mg/l/d")
     assert approx(db.Convert("density generation", "mg/l/d", "kg/m3/d", 1.0)) == 0.001
 
 
-def testMolarDensity(db):
+def testMolarDensity(db) -> None:
     db.CheckQuantityTypeUnit("amount of a substance", "gmole/m3")
     db.CheckQuantityTypeUnit("concentration of B", "gmole/m3")
 
 
-def testPartsPerMillionByVolumeConcentration(db):
+def testPartsPerMillionByVolumeConcentration(db) -> None:
     assert (
         approx(
             db.Convert(
@@ -56,25 +56,25 @@ def testPartsPerMillionByVolumeConcentration(db):
     )
 
 
-def testKPaPerSecond(db):
+def testKPaPerSecond(db) -> None:
     assert approx(db.Convert("dynamic viscosity", "Pa.s", "kPa.s", 1000.0)) == 1
 
 
-def testPartsPerMillionVolume(db):
+def testPartsPerMillionVolume(db) -> None:
     quantity_type = db.GetCategoryInfo("relative proportion").quantity_type
     db.CheckQuantityTypeUnit(quantity_type, "ppmv")
 
 
-def testPerTimeSquared(db):
+def testPerTimeSquared(db) -> None:
     quantity_type = db.GetCategoryInfo("per time squared").quantity_type
     db.CheckQuantityTypeUnit(quantity_type, "1/d^2")
 
 
-def testNoUnit(db):
+def testNoUnit(db) -> None:
     db.CheckQuantityTypeUnit("dimensionless", "-")
 
 
-def testFluidConsistencyQuantityAndConversions(db):
+def testFluidConsistencyQuantityAndConversions(db) -> None:
     # Checking the quantity type.
     db.CheckQuantityType("fluid consistency")
 
@@ -130,19 +130,19 @@ def testFluidConsistencyQuantityAndConversions(db):
     assert approx(DoConversion("eq.cp", "lbf.s^n/100ft2", 250.0)) == 0.5250109
 
 
-def testBblPerMeters(db):
+def testBblPerMeters(db) -> None:
     assert approx(db.Convert("volume per length", "bbl/ft", "bbl/m", 1)) == 1 / 0.3048
 
 
-def testBblPerSecond(db):
+def testBblPerSecond(db) -> None:
     assert approx(db.Convert("volume flow rate", "bbl/hr", "bbl/s", 1)) == 1 / 3600
 
 
-def testConcentration(db):
+def testConcentration(db) -> None:
     assert approx(db.Convert("concentration", "g/L", "mg/L", 1)) == 1000.0
 
 
-def testVolumeFractionPerTemperature(db):
+def testVolumeFractionPerTemperature(db) -> None:
     expected_result = db.Convert("volumetric thermal expansion", "1/degC", "1/degF", 1)
     obtained_result = db.Convert(
         "volume fraction per temperature", "(m3/m3)/degC", "(m3/m3)/degF", 1
@@ -154,7 +154,7 @@ def testVolumeFractionPerTemperature(db):
     assert obtained_result == expected_units
 
 
-def testVolumePerWtpercent(db):
+def testVolumePerWtpercent(db) -> None:
     ft3_wtpercent_to_m3_wtpercent = db.Convert(
         "volume per wtpercent", "ft3/wtpercent", "m3/wtpercent", 25 / 1
     )
@@ -166,7 +166,7 @@ def testVolumePerWtpercent(db):
     assert approx(m3_to_wtpercent_to_ft3_to_wtpercent) == 25
 
 
-def testMassPerMol(db):
+def testMassPerMol(db) -> None:
     gpermol_to_kgpermol = db.Convert("mass per mol", "g/mol", "kg/mol", 1000 / 1)
     kgpermol_to_gpermol = db.Convert("mass per mol", "kg/mol", "g/mol", 1)
 
@@ -175,7 +175,7 @@ def testMassPerMol(db):
     assert approx(db.Convert("mass per mol", "g/mol", "lb/lbmole", 1)) == 1
 
 
-def testInjectivityFactor(db):
+def testInjectivityFactor(db) -> None:
     quantity_type = db.GetCategoryInfo("injectivity factor").quantity_type
 
     db.CheckQuantityType(quantity_type)
@@ -193,7 +193,7 @@ def testInjectivityFactor(db):
     assert approx(converted_value) == 1.1802270983e-10
 
 
-def testTemperaturePerLengthdegCP30m():
+def testTemperaturePerLengthdegCP30m() -> None:
     u1 = units.Scalar("temperature per length", 1.0, "K/m")
     u2 = units.Scalar("temperature per length", 30.0, "degC/30m")
 
@@ -201,32 +201,32 @@ def testTemperaturePerLengthdegCP30m():
     assert approx(u2.GetValue("K/m")) == 1.0
 
 
-def testMassPerTimePerArea(db):
+def testMassPerTimePerArea(db) -> None:
     secs_to_days = 60 * 60 * 24
     assert approx(db.Convert("mass per time per area", "kg/m2.s", "kg/m2.d", 1)) == 1 * secs_to_days
 
 
-def testAccelerationLinearMetersPerMin2(db):
+def testAccelerationLinearMetersPerMin2(db) -> None:
     assert approx(db.Convert("acceleration linear", "m/s2", "m/min2", 2)) == 7200
     assert approx(db.Convert("acceleration linear", "m/min2", "m/s2", 10800)) == 3
 
 
-def testAccelerationLinearFeetPerMin2(db):
+def testAccelerationLinearFeetPerMin2(db) -> None:
     assert approx(db.Convert("acceleration linear", "ft/s2", "ft/min2", 2)) == 7200
     assert approx(db.Convert("acceleration linear", "ft/min2", "ft/s2", 10800)) == 3
 
 
-def testMassConcentration(db):
+def testMassConcentration(db) -> None:
     assert approx(db.Convert("mass concentration", "Euc", "g/g", 2)) == 2
     assert approx(db.Convert("mass concentration", "Euc", "g/100g", 2)) == 200
     assert approx(db.Convert("mass concentration", "Euc", "lbm/lbm", 2)) == 2
 
 
-def testSpecificVolume(db):
+def testSpecificVolume(db) -> None:
     assert approx(db.Convert("specific volume", "m3/kg", "l/mg", 1.0)) == 0.001
 
 
-def testViscosityPerPressure(db):
+def testViscosityPerPressure(db) -> None:
     assert approx(db.Convert("viscosity per pressure", "cP/kPa", "cP/psi", 10.0)) == 68.9475729
 
     assert approx(db.Convert("viscosity per pressure", "cP/kPa", "cP/(kgf/cm2)", 10.0)) == 980.665
@@ -240,28 +240,28 @@ def testViscosityPerPressure(db):
     assert approx(db.Convert("viscosity per pressure", "cP/(kgf/cm2)", "cP/kPa", 10.0)) == 0.1019716
 
 
-def testForcePerLength(db):
+def testForcePerLength(db) -> None:
     assert approx(db.Convert("force per length", "N/m", "kgf/m", 1.0)) == 0.101971621
 
 
-def testMiligramPerGram(db):
+def testMiligramPerGram(db) -> None:
     assert approx(db.Convert("mass concentration", "mg/g", "g/g", 2.0)) == 0.002
 
 
-def testGramsPerBarrel(db):
+def testGramsPerBarrel(db) -> None:
     db.CheckQuantityTypeUnit("concentration", "g/bbl")
 
 
-def testSiemens(db):
+def testSiemens(db) -> None:
     assert approx(db.Convert("conductivity", "S/m", "uS/m", 1.0)) == 1000000.0
 
 
-def testStrokeFrequency(db):
+def testStrokeFrequency(db) -> None:
     db.CheckQuantityTypeUnit("stroke frequency", "spm")
     assert approx(db.Convert("stroke frequency", "spm", "sps", 150.0)) == 2.5
 
 
-def testPowerPerWeight(db):
+def testPowerPerWeight(db) -> None:
     db.CheckQuantityTypeUnit("power per mass", "W/kg")
     db.CheckQuantityTypeUnit("power per weight", "W/kg")
 
@@ -269,7 +269,7 @@ def testPowerPerWeight(db):
     assert approx(db.Convert("power per weight", "kW/kg", "W/kg", 1.0)) == 1000.0
 
 
-def testSelfInductance(db):
+def testSelfInductance(db) -> None:
     assert approx(db.Convert("self inductance per length", "H/m", "H/km", 1.0), rel=0.01) == 1000
 
     assert (
@@ -295,7 +295,7 @@ def testSelfInductance(db):
     )
 
 
-def testConcentrationPerSquareTime(db):
+def testConcentrationPerSquareTime(db) -> None:
     db.CheckQuantityTypeUnit("concentration per square time", "mg/l/d2")
     db.CheckQuantityTypeUnit("concentration per square time", "kg/m3/d2")
 
@@ -306,19 +306,19 @@ def testConcentrationPerSquareTime(db):
     assert approx(db.Convert("concentration per square time", "kg/m3/d2", "mg/l/d2", 1.0)) == 1000.0
 
 
-def testVolumeInCubicMicrometres(db):
+def testVolumeInCubicMicrometres(db) -> None:
     obtained = db.Convert("volume", "m3", "um3", 1.0)
     expected = 1e18
     assert approx(obtained, rel=1e-12) == expected
 
 
-def testVolumeFlowRateInCubicMicrometresPerSecond(db):
+def testVolumeFlowRateInCubicMicrometresPerSecond(db) -> None:
     obtained = db.Convert("volume flow rate", "m3/s", "um3/s", 1.0)
     expected = 1e18
     assert approx(obtained, rel=1e-12) == expected
 
 
-def testFlowCoefficient(db):
+def testFlowCoefficient(db) -> None:
     obtained = db.Convert("flow coefficient", "(galUS/min)/(psi^0.5)", "(m3/s)/(Pa^0.5)", 1.0)
     expected = 7.59805421208337e-07
     assert approx(obtained, rel=1e-12) == expected
@@ -328,7 +328,7 @@ def testFlowCoefficient(db):
     assert approx(obtained, rel=1e-12) == expected
 
 
-def testHertzPerSecond():
+def testHertzPerSecond() -> None:
     from barril.units import Scalar
 
     assert approx(Scalar(1, "rpm").GetValue("Hz")) == 1 / 60.0
@@ -337,14 +337,14 @@ def testHertzPerSecond():
     assert approx(Scalar(1, "rpm/s").GetValue("Hz/s")) == 1 / 60.0
 
 
-def testFluidGasConcentration():
+def testFluidGasConcentration() -> None:
     from barril.units import Scalar
 
     assert approx(Scalar(1, "tgu").GetValue("ppm")) == 333.33
     assert approx(Scalar(1, "tgu").GetValue("%")) == 0.033333
 
 
-def testPerMicrometre(db):
+def testPerMicrometre(db) -> None:
     per_micrometre = units.Scalar("per length", 1.0, "1/um")
     per_metre = per_micrometre.CreateCopy(unit="1/m")
     per_inch = per_micrometre.CreateCopy(unit="1/in")
